function fMRI1 (handles, x, y, z)
% displays coronal, sagittal, and horizontal slices of the anatomical MRI
% data, whose position is specified by the input x, y, and z coordinates, 
% respectively -- adapted from Idan Blank's original code file 

% original code file loaded the anatomical MRI data file from the web       
% f=urlwrite('http://web.mit.edu/iblank/www/ComputationalBiologyWorkshop/brainAnatomical.txt','anat.mat');
% load(f,'-ascii')
% anat = reshape(anat,[189,157,136]);

% create local variable to refer to anatomical data matrix
im = handles.anat;

% display coronal slice
coronalIm = flip(permute(im,[3,2,1]),1);        
slice = coronalIm(:,:,x);
axes(handles.axes1)
imagesc(slice)
colormap gray
hold on
plot(y,size(slice,1)+1-z,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-z size(slice,1)+1-z], '--r', 'linewidth', 2);
plot([y y], [0 size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([1.5 size(slice,2)+0.5 size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 size(slice,1)+0.5 size(slice,1)+0.5 1.5], '-b', 'linewidth', 3)
text(size(slice,2)/2, 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Coronal Slice', 'fontsize', 20, 'fontweight','bold', 'color','b');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display sagittal slice
sagittalIm = flip(permute(im,[3,1,2]),1);       
slice = sagittalIm(:,:,y);
axes(handles.axes2)
imagesc(slice)
colormap gray
hold on
plot(x,size(slice,1)+1-z,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-z size(slice,1)+1-z], '--r', 'linewidth', 2);
plot([x x], [0 size(slice,1)], '--b', 'linewidth', 2);
plot([1.5 size(slice,2)+0.5 size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 size(slice,1)+0.5 size(slice,1)+0.5 1.5], '-', 'color', [0 0.7 0], 'linewidth', 3)
text(size(slice,2)/2, 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Sagittal Slice', 'fontsize', 20, 'fontweight','bold', 'color',[0 0.7 0]);
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display horizontal slice
slice = flip(im(:,:,z),1);   
axes(handles.axes3)
imagesc(slice);
colormap gray
hold on
plot(y,size(slice,1)+1-x,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-x size(slice,1)+1-x], '--b', 'linewidth', 2);
plot([y y], [0 size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([1.5 size(slice,2)+0.5 size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 size(slice,1)+0.5 size(slice,1)+0.5 1.5], '-r', 'linewidth', 3)
text(size(slice,2)/2, 4, 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'middle');
title('Horizontal Slice', 'fontsize', 20, 'fontweight','bold', 'color','r');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display 3D graphical depiction of slices on head
axes(handles.axes4)
fMRI3D(1,x,y,z);
