function fMRI2 (handles)
% displays a particular set of coronal, sagittal, and horizontal slices of 
% the fMRI data -- adapted from Idan Blank's original code file 

% original code file loaded the fMRI data file from the web           
% f=urlwrite('http://web.mit.edu/iblank/www/ComputationalBiologyWorkshop/brainFunctionalSingleScaled.txt','funcIm.mat');
% load('funcIm.mat','-ascii')
% func = reshape(funcIm,[95,79,69]);

% create local variable to refer to anatomical data matrix
func = handles.funcIm;
v = [45 68 24];
im = 0.9*func;

% display coronal slice
coronalIm = flip(permute(im,[3,2,1]),1);
slice = coronalIm(:,:,v(1));
axes(handles.axes1)
cla
[rows, cols] = size(slice);
temp = zeros(2*rows,2*cols);
for r = 1:rows
    for c = 1:cols
        temp((2*r):(2*r+1), (2*c):(2*c+1)) = slice(r,c);
    end
end   
imagesc(temp)
colormap gray
hold on
plot(2*v(2),2*size(slice,1)+1-2*v(3),'ow','markersize',16,'linewidth',2);
plot([0 2*size(slice,2)], [2*size(slice,1)+1-2*v(3) 2*size(slice,1)+1-2*v(3)], '--r', 'linewidth', 2);
plot([2*v(2) 2*v(2)], [0 2*size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([1.5 2*size(slice,2)+0.5 2*size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 2*size(slice,1)+0.5 2*size(slice,1)+0.5 1.5], '-b', 'linewidth', 2)
text(2*(size(slice,2)/2), 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(2*(size(slice,2)/2), 2*size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, 2*(size(slice,1)/2), 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(2*size(slice,2)-4, 2*(size(slice,1)/2), 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Coronal Slice', 'fontsize', 20, 'fontweight','bold', 'color','b');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display sagittal slice
sagittalIm = flip(permute(im,[3,1,2]),1);
slice = sagittalIm(:,:,v(2));
axes(handles.axes2)
cla
[rows, cols] = size(slice);
temp = zeros(2*rows,2*cols);
for r = 1:rows
    for c = 1:cols
        temp((2*r):(2*r+1), (2*c):(2*c+1)) = slice(r,c);
    end
end   
imagesc(temp)
colormap gray
hold on
plot(2*v(1),2*size(slice,1)+1-2*v(3),'ow','markersize',16,'linewidth',2);
plot([0 2*size(slice,2)], [2*size(slice,1)+1-2*v(3) 2*size(slice,1)+1-2*v(3)], '--r', 'linewidth', 2);
plot([2*v(1) 2*v(1)], [0 2*size(slice,1)], '--b', 'linewidth', 2);
plot([1.5 2*size(slice,2)+0.5 2*size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 2*size(slice,1)+0.5 2*size(slice,1)+0.5 1.5], '-', 'color', [0 0.7 0], 'linewidth', 2)
text(2*(size(slice,2)/2), 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(2*(size(slice,2)/2), 2*size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, 2*(size(slice,1)/2), 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(2*(size(slice,2)-4), 2*(size(slice,1)/2), 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Sagittal Slice', 'fontsize', 20, 'fontweight','bold', 'color',[0 0.7 0]);
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display horizontal slice
axes(handles.axes3)
slice = flip(im(:,:,v(3)),1);
cla
[rows, cols] = size(slice);
temp = zeros(2*rows,2*cols);
for r = 1:rows
    for c = 1:cols
        temp((2*r):(2*r+1), (2*c):(2*c+1)) = slice(r,c);
    end
end   
imagesc(temp)
colormap gray
hold on
plot(2*v(2),2*size(slice,1)+1-2*v(1),'ow','markersize',16,'linewidth',2);
plot([0 2*size(slice,2)], [2*size(slice,1)+1-2*v(1) 2*size(slice,1)+1-2*v(1)], '--b', 'linewidth', 2);
plot([2*v(2) 2*v(2)], [0 2*size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([1.5 2*size(slice,2)+0.5 2*size(slice,2)+0.5 1.5 1.5], ...
    [1.5 1.5 2*size(slice,1)+0.5 2*size(slice,1)+0.5 1.5], '-r', 'linewidth', 2)
text(2*(size(slice,2)/2), 4, 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(2*(size(slice,2)/2), 2*size(slice,1)-3, 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, 2*(size(slice,1)/2)+10, 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(2*size(slice,2)-4, 2*size(slice,1)/2+10, 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Horizontal Slice', 'fontsize', 20, 'fontweight','bold', 'color','r');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

% display 3D graphical depiction of slices on head
axes(handles.axes4)
fMRI3D(0,45,68,24);


      