function fMRI3D (which, x, y, z) 
% creates a 3D graphical depiction of the location of three slices of an
% MRI (which = 1) or fMRI (which = 0) scan, where x is the position of the 
% coronal slice (MRI: 1 to 189, from back to front), y is the position of 
% the sagittal slice (MRI: 1 to 157, from right to left), and z is the 
% position of the horizontal slice (MRI: 1 to 136, from bottom to top)
% (for fMRI data, there's about half as many slices in each direction)

% s is used to adjust coordinates for fMRI data
if (which == 1)     % MRI data
    s = 1;
else                % fMRI data
    s = 0.5;
end

% display blue, green, and red planes at the locations of the coronal,
% sagittal, and horizontal slices, respectively
fill3([x x x x x], s*[1 157 157 1 1], s*[1 1 136 136 1], 'b')
hold on
fill3(s*[1 189 189 1 1], [y y y y y], s*[1 1 136 136 1], 'g')
fill3(s*[1 189 189 1 1], s*[1 1 157 157 1], [z z z z z], 'r')
axis(s*[1 189 1 157 1 136])
xlabel('coronal', 'FontSize', 16)
ylabel('sagittal', 'FontSize', 16)
zlabel('horizontal', 'FontSize', 16)
axis equal

% display a "head" in the volume, to help orient the user to the locations
% of the 3D slides
[xs, ys, zs] = sphere;      % make head
xs = 95 + 85*xs;
ys = 79 + 70*ys;
zs = 68 + 60*zs;
mesh(s*xs, s*ys, s*zs, 'FaceColor', 'w', 'EdgeColor', 'k')
[xs, ys, zs] = sphere;      % make black eyes
xs = 5*xs + 165;
ys = 5*ys + 110;
zs = 5*zs + 85;
surf(s*xs, s*ys, s*zs, 'FaceColor', 'k', 'EdgeColor', 'k')
[xs, ys, zs] = sphere;     
xs = 5*xs + 165;
ys = 5*ys + 48;
zs = 5*zs + 85;
surf(s*xs, s*ys, s*zs, 'FaceColor', 'k', 'EdgeColor', 'k')
[xs, ys, zs] = sphere;      % make red nose
xs = 5*xs + 175;
ys = 5*ys + 79;
zs = 5*zs + 48;
surf(s*xs, s*ys, s*zs, 'FaceColor', 'r', 'EdgeColor', 'r')
hold off

axis tight
view(35,20)                 % set azimuth and elevation for initial view          
rotate3d on                 % allow user to change the 3D view


